# coding: utf-8

"""
    Core Operations

    The Sparkfly Platform provides a full lifecycle for promotions and rewards from creation to distribution to settlement. The platform integrates in real-time at the point-of-sale and provides item level discounting and tracking. The capabilities of the Sparkfly Platform are available through the use of the Sparkfly Platform API.  The Sparkfly documentation site is under development. If the documentation you're after isn't available here, please contact support@sparkfly.com and we will get you what you need.

    The version of the OpenAPI document: 1.0
    Contact: support@sparkfly.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sparkfly_api_client.api.ctm_api import CtmApi


class TestCtmApi(unittest.IsolatedAsyncioTestCase):
    """CtmApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = CtmApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_get_ctm_custom_messages(self) -> None:
        """Test case for get_ctm_custom_messages

        CTM Custom Messages
        """
        pass

    async def test_get_ctm_store(self) -> None:
        """Test case for get_ctm_store

        CTM Stores
        """
        pass

    async def test_get_show_ctm(self) -> None:
        """Test case for get_show_ctm

        CTM Show Response
        """
        pass

    async def test_post_allocate_ctm(self) -> None:
        """Test case for post_allocate_ctm

        CTM Allocate
        """
        pass

    async def test_post_deallocate_ctm(self) -> None:
        """Test case for post_deallocate_ctm

        CTM Dealocate
        """
        pass

    async def test_post_qitems_ctm(self) -> None:
        """Test case for post_qitems_ctm

        CTM Qitems
        """
        pass

    async def test_post_update_ctm(self) -> None:
        """Test case for post_update_ctm

        CTM Update Response
        """
        pass

    async def test_post_update_ctm_siteid(self) -> None:
        """Test case for post_update_ctm_siteid

        CTM Update Response
        """
        pass

    async def test_put_show_ctm(self) -> None:
        """Test case for put_show_ctm

        CTM Show Response
        """
        pass

    async def test_put_transaction_update_ctm(self) -> None:
        """Test case for put_transaction_update_ctm

        CTM Transaction Update
        """
        pass

    async def test_put_update_ctm(self) -> None:
        """Test case for put_update_ctm

        CTM Update Response
        """
        pass


if __name__ == '__main__':
    unittest.main()
