# coding: utf-8

"""
    Core Operations

    The Sparkfly Platform provides a full lifecycle for promotions and rewards from creation to distribution to settlement. The platform integrates in real-time at the point-of-sale and provides item level discounting and tracking. The capabilities of the Sparkfly Platform are available through the use of the Sparkfly Platform API.  The Sparkfly documentation site is under development. If the documentation you're after isn't available here, please contact support@sparkfly.com and we will get you what you need.

    The version of the OpenAPI document: 1.0
    Contact: support@sparkfly.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sparkfly_api_client.api.items_api import ItemsApi


class TestItemsApi(unittest.IsolatedAsyncioTestCase):
    """ItemsApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = ItemsApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_delete_item_sets_item_set_id(self) -> None:
        """Test case for delete_item_sets_item_set_id

        Delete an Item Set
        """
        pass

    async def test_delete_item_sets_item_set_id_items_id(self) -> None:
        """Test case for delete_item_sets_item_set_id_items_id

        Remove Item from Set
        """
        pass

    async def test_delete_items_id(self) -> None:
        """Test case for delete_items_id

        Delete Item
        """
        pass

    async def test_get_item_sets(self) -> None:
        """Test case for get_item_sets

        Item Set Index
        """
        pass

    async def test_get_item_sets_item_set_id(self) -> None:
        """Test case for get_item_sets_item_set_id

        Get an Item Set
        """
        pass

    async def test_get_item_sets_item_set_id_items(self) -> None:
        """Test case for get_item_sets_item_set_id_items

        Item Set Item Index
        """
        pass

    async def test_get_items(self) -> None:
        """Test case for get_items

        Item Index
        """
        pass

    async def test_get_items_id(self) -> None:
        """Test case for get_items_id

        Get Item
        """
        pass

    async def test_post_item_sets(self) -> None:
        """Test case for post_item_sets

        Item Set Create
        """
        pass

    async def test_post_item_sets_item_set_id_items_id(self) -> None:
        """Test case for post_item_sets_item_set_id_items_id

        Add Item to Set
        """
        pass

    async def test_post_items(self) -> None:
        """Test case for post_items

        Create Item
        """
        pass

    async def test_put_item_sets_item_set_id(self) -> None:
        """Test case for put_item_sets_item_set_id

        Update an Item Set
        """
        pass

    async def test_put_items_id(self) -> None:
        """Test case for put_items_id

        Update Item
        """
        pass


if __name__ == '__main__':
    unittest.main()
