# coding: utf-8

"""
    Core Operations

    The Sparkfly Platform provides a full lifecycle for promotions and rewards from creation to distribution to settlement. The platform integrates in real-time at the point-of-sale and provides item level discounting and tracking. The capabilities of the Sparkfly Platform are available through the use of the Sparkfly Platform API.  The Sparkfly documentation site is under development. If the documentation you're after isn't available here, please contact support@sparkfly.com and we will get you what you need.

    The version of the OpenAPI document: 1.0
    Contact: support@sparkfly.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sparkfly_api_client.api.offers_api import OffersApi


class TestOffersApi(unittest.IsolatedAsyncioTestCase):
    """OffersApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = OffersApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_delete_offers_offer_id(self) -> None:
        """Test case for delete_offers_offer_id

        Delete an Offer
        """
        pass

    async def test_get_offers(self) -> None:
        """Test case for get_offers

        List all Offers
        """
        pass

    async def test_get_offers_offer_id(self) -> None:
        """Test case for get_offers_offer_id

        Find an Offer
        """
        pass

    async def test_post_offers(self) -> None:
        """Test case for post_offers

        Create an Offer
        """
        pass

    async def test_put_offers_offer_id(self) -> None:
        """Test case for put_offers_offer_id

        Update an Offer
        """
        pass


if __name__ == '__main__':
    unittest.main()
