# coding: utf-8

"""
    Core Operations

    The Sparkfly Platform provides a full lifecycle for promotions and rewards from creation to distribution to settlement. The platform integrates in real-time at the point-of-sale and provides item level discounting and tracking. The capabilities of the Sparkfly Platform are available through the use of the Sparkfly Platform API.  The Sparkfly documentation site is under development. If the documentation you're after isn't available here, please contact support@sparkfly.com and we will get you what you need.

    The version of the OpenAPI document: 1.0
    Contact: support@sparkfly.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sparkfly_api_client.api.offer_states_api import OfferStatesApi


class TestOfferStatesApi(unittest.IsolatedAsyncioTestCase):
    """OfferStatesApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = OfferStatesApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_get_members_member_id_offer_states(self) -> None:
        """Test case for get_members_member_id_offer_states

        Get all Offer States
        """
        pass

    async def test_get_members_member_id_offer_states_offer_state_id(self) -> None:
        """Test case for get_members_member_id_offer_states_offer_state_id

        Get Offer State by Offer State ID
        """
        pass

    async def test_get_members_member_id_offers_offer_id(self) -> None:
        """Test case for get_members_member_id_offers_offer_id

        Get Offer State by Offer ID
        """
        pass

    async def test_get_members_offer_states(self) -> None:
        """Test case for get_members_offer_states

        Get Offer State from Query Parameters
        """
        pass

    async def test_post_members_id_offer_states_issue(self) -> None:
        """Test case for post_members_id_offer_states_issue

        Issue an Offer to a member (high throughput)
        """
        pass

    async def test_post_members_member_id_offer_states(self) -> None:
        """Test case for post_members_member_id_offer_states

        Create Offer State
        """
        pass

    async def test_post_members_member_id_offer_states_offerstate_id(self) -> None:
        """Test case for post_members_member_id_offer_states_offerstate_id

        Update Offer State - Post
        """
        pass

    async def test_post_members_member_id_offer_states_offerstate_id_void(self) -> None:
        """Test case for post_members_member_id_offer_states_offerstate_id_void

        Void Offer State
        """
        pass

    async def test_post_members_member_id_offer_states_offerstate_id_voidmember_identifier_member_identifier(self) -> None:
        """Test case for post_members_member_id_offer_states_offerstate_id_voidmember_identifier_member_identifier

        Void Offer State by Member Identifier
        """
        pass

    async def test_post_members_offer_states(self) -> None:
        """Test case for post_members_offer_states

        Create Offer State from Query Parameters
        """
        pass

    async def test_put_members_member_id_offer_states_offer_state_id(self) -> None:
        """Test case for put_members_member_id_offer_states_offer_state_id

        Update Offer State
        """
        pass


if __name__ == '__main__':
    unittest.main()
